@@ -1,5 +1,5 @@
 package CGI::Builder::Test ;
-$VERSION = 1.0 ;
+$VERSION = 1.01 ;
 
 ; use strict
 # statements from now on are needed just when testing
@@ -57,9 +57,13 @@ __END__
 
 CGI::Builder::Test - Adds some testing methods to your build
 
-=head1 VERSION 1.0
+=head1 VERSION 1.01
 
-Included in CGI-Builder 1.0 distribution. The distribution includes:
+Included in CGI-Builder 1.01 distribution.
+
+The latest versions changes are reported in the F<Changes> file in this distribution.
+
+The distribution includes:
 
 =over
 
